*[API]: Application Programming Interface
*[BIPM]: Bureau International des Poids et Mesures / International Bureau of Weights and Measures
*[CMC]: Calibration and Measurement Capabilities
*[CRM]: Certified Reference Material
*[KCDB]: Key Comparison Database
*[NMI]: National Metrology Institute
*[RMO]: Regional Metrology Organization
